@@ -73,12 +73,44 @@ void PrintHelp()
 	printf("  -nofl          : Disable Frame Limiter\n");
 	printf("  -mcd1 FILE     : Set memory card 1 file\n");
 	printf("  -mcd2 FILE     : Set memory card 2 file\n");
+	printf("  -region VALUE  : Set PSX region\n");
+	printf("                   -1=Auto (Default)\n");
+	printf("                    0=NTSC\n");
+	printf("                    1=PAL\n");
 
 	printf("\nGPU Options:\n");
 	printf("  -gles          : Use the GLES plugin (gpuGLES.so)\n");
 	printf("  -4all          : Use the PCSX4All plugin (gpuPCSX4ALL.so)\n");
 	printf("  -oldgpu        : Use the peops plugin (gpu_peops.so)\n");
 	printf("  -unai          : Use the unai plugin (gpu_unai.so)\n");
+
+/*
+	printf("\nNeon Options (default GPU):\n");
+	printf("  -neon_interlace VALUE : Set interlce mode\n");
+	printf("                          0=Off\n");
+	printf("                          1=On\n");
+	printf("                          2=Auto (Default)\n");
+*/
+
+/*
+	printf("\nGles Options:\n");
+	printf("  -gles_dithering VALUE : Enable/disable dithering [0/1]\n");
+	printf("  -gles_mask VALUE      : Enable/disable mask detect [0/1]\n");
+	printf("  -gles_filtering VALUE : Texture Filtering\n");
+	printf("                          0=None\n");
+	printf("                          1=Standard\n");
+	printf("                          2=Extended\n");
+	printf("                          3=Standard-sprites\n");
+	printf("                          4=Extended-sprites\n");
+	printf("                          5=Standard+sprites\n");
+	printf("                          6=Extended+sprites]\n");
+	printf("  -gles_fbtex VALUE     : Framebuffer Textures\n");
+	printf("                          0=Emulated VRam\n");
+	printf("                          1=Black\n");
+	printf("                          2=Card\n");
+	printf("                          3=Card+soft\n");
+	printf("  -gles_vram VALUE      : Texture RAM size in MB [4-128]\n");
+*/
 }
 
 int maemo_main(int argc, char **argv)
@@ -102,6 +134,7 @@ int maemo_main(int argc, char **argv)
 	snprintf(Config.PatchesDir, sizeof(Config.PatchesDir), "/opt/maemo/usr/games" PATCHES_DIR);
 	Config.PsxAuto = 1;
 	pl_rearmed_cbs.frameskip = -1;
+	strcpy(Config.Bios, "HLE");
 
 	// read command line options
 	for (i = 1; i < argc; i++) {
@@ -129,6 +162,13 @@ int maemo_main(int argc, char **argv)
 			else
 				pl_rearmed_cbs.frameskip = tv_reg;
 		}
+		else if (!strcmp(argv[i],"-region")) {
+			int psx_reg = atol(argv[++i]);
+			if (psx_reg == 0 || psx_reg == 1){				
+				Config.PsxAuto = 0;
+				Config.PsxType = psx_reg;
+			}
+		}
 		else if (!strcmp(argv[i], "-fullscreen"))		g_maemo_opts |= 2;
 		else if (!strcmp(argv[i], "-accel"))				g_maemo_opts |= 4;
 		else if (!strcmp(argv[i], "-sputhreaded"))		iUseTimer=1;
@@ -152,6 +192,18 @@ int maemo_main(int argc, char **argv)
 		else if (!strcmp(argv[i], "-nofl")) 		g_opts |=OPT_NO_FRAMELIM;
 		else if (!strcmp(argv[i], "-mcd1")) 	sprintf(Config.Mcd1, "%s", argv[++i]);
 		else if (!strcmp(argv[i], "-mcd2")) 	sprintf(Config.Mcd2, "%s", argv[++i]);
+
+/*
+		else if (!strcmp(argv[i], "-neon_interlace")) 	pl_rearmed_cbs.gpu_neon.allow_interlace = atol(argv[++i]);
+*/
+
+/*
+		else if (!strcmp(argv[i], "-gles_dithering")) 	pl_rearmed_cbs.gpu_peopsgl.bDrawDither = atol(argv[++i]);
+		else if (!strcmp(argv[i], "-gles_mask")) 	pl_rearmed_cbs.gpu_peopsgl.iUseMask = atol(argv[++i]);
+		else if (!strcmp(argv[i], "-gles_filtering")) 	pl_rearmed_cbs.gpu_peopsgl.iFilterType = atol(argv[++i]);
+		else if (!strcmp(argv[i], "-gles_fbtex")) 	pl_rearmed_cbs.gpu_peopsgl.iFrameTexType = atol(argv[++i]);
+		else if (!strcmp(argv[i], "-gles_vram")) 	pl_rearmed_cbs.gpu_peopsgl.iVRamSize = atol(argv[++i]);
+*/
 	}
 
 	hildon_init(&argc, &argv);
@@ -214,6 +266,9 @@ int maemo_main(int argc, char **argv)
 		}
 	}
 
+	if (Config.HLE)
+		printf("Note: running without BIOS, expect compatibility problems\n");
+
 	dfinput_activate();
 	pl_timing_prepare(Config.PsxType);
 
