@@ -46,34 +46,9 @@ extern "C" {
 #define GREEN(x) ((x>>8) & 0xff)
 #define COLOR(x) (x & 0xffffff)
 
-#ifdef _WINDOWS
-#include "Externals.h"
-#include "plugin.h"
-#include <gl/gl.h>
-#else
-//#ifndef MAEMO_CHANGES
-//	#include "psxCommon.h"
-//#else
-//	#include "../psxCommon.h"
-//#endif
+
 #include "gpuExternals.h"
-#ifdef __NANOGL__
-#include <gl/gl.h>
-#else
-#ifdef SOFT_LINKAGE
-#pragma softfp_linkage
-#endif
-#ifndef MAEMO_CHANGES
-	#include <gles/gl.h> // for opengl es types 
-	#include <gles/egltypes.h>
-#else
-#include "gpuStdafx.h"
-#endif
-#ifdef SOFT_LINKAGE
-#pragma no_softfp_linkage
-#endif
-#endif
-#endif
+
 /////////////////////////////////////////////////////////////////////////////
 
 #define CALLBACK
@@ -81,12 +56,13 @@ extern "C" {
 #define bool unsigned short
 
 typedef struct {
-	u32 ulFreezeVersion;
-	u32 ulStatus;
-	u32 ulControl[256];
-	u8 psxVRam[1024*1024*2];
+	unsigned int ulFreezeVersion;
+	unsigned int ulStatus;
+	unsigned int ulControl[256];
+	unsigned char psxVRam[1024*1024*2];
 } GPUFreeze_t;
 
+#if 0
 long CALLBACK GPUinit();
 long CALLBACK GPUshutdown();
 long CALLBACK GPUopen(int hwndGPU);
@@ -101,15 +77,15 @@ long CALLBACK GPUdmaChain(unsigned long * baseAddrL, unsigned long addr);
 void CALLBACK GPUupdateLace(void);
 void CALLBACK GPUmakeSnapshot(void);
 long CALLBACK GPUfreeze(unsigned long ulGetFreezeData,GPUFreeze_t * pF);
-long CALLBACK GPUgetScreenPic(u8 * pMem);
-long CALLBACK GPUshowScreenPic(u8 * pMem);
+long CALLBACK GPUgetScreenPic(unsigned char * pMem);
+long CALLBACK GPUshowScreenPic(unsigned char * pMem);
 //void CALLBACK GPUkeypressed(int keycode);
 //void CALLBACK GPUdisplayText(s8 * pText);
 //void CALLBACK GPUclearDynarec(void (CALLBACK *callback)(void));
 long CALLBACK GPUconfigure(void);
 long CALLBACK GPUtest(void);
 void CALLBACK GPUabout(void);
-
+#endif
 
 void           DoSnapShot(void);
 void		   GPUvSinc(void);
@@ -121,8 +97,8 @@ void           CheckVRamRead(int x, int y, int dx, int dy, bool bFront);
 void           CheckVRamReadEx(int x, int y, int dx, int dy);
 void           SetFixes(void);
 
-void PaintPicDot(u8 * p,u8 c);
-//void DrawNumBorPic(u8 *pMem, int lSelectedSlot);
+void PaintPicDot(unsigned char * p,unsigned char c);
+//void DrawNumBorPic(unsigned char *pMem, int lSelectedSlot);
 void ResizeWindow();
 
 ////////////////////////////////////////////////////////////////////////////
